@@ -13,9 +13,21 @@
  Original:	March 1990
 
  $Log:	DevServerP.h,v $
- * Revision 8.18  2000/11/12  13:24:04  13:24:04  goetz (Andy Goetz)
- * added dynamic error handling; improved TANGO error treatment
+ * Revision 8.20  2001/01/08  13:14:55  13:14:55  goetz (Andy Goetz)
+ * added patch by B.Pedersen to support querying events
  * 
+ Revision 8.31  2000/07/28 09:59:52  dserver
+ BP: added dev_query_event to get event parameters
+     -> new data struture  for event list in server
+        events have to be registered by the server,
+        similar to commands.
+
+ Revision 8.19  2000/12/11 12:06:48  goetz
+ fixed bugs with TANGO interface returning unsigned values and states
+
+ Revision 8.18  2000/11/12 13:24:04  goetz
+ added dynamic error handling; improved TANGO error treatment
+
  Revision 8.17  1900/09/26 13:36:39  goetz
  tango_dev_putget() and tango_dev_putget_raw() implement immediate reconnection
 
@@ -210,7 +222,7 @@
  */
 #ifdef _IDENT
 static char DevServerPh[] =
-"@(#)$Header: DevServerP.h,v 8.18 2000/11/12 13:24:04 goetz Rel $";
+"@(#)$Header: DevServerP.h,v 8.20 2001/01/08 13:14:55 goetz Rel $";
 #endif /* _IDENT */
 
 /*
@@ -230,6 +242,8 @@ typedef struct _DevServerClassPart {
                DevBoolean           class_inited;
                int                  n_commands;
                DevCommandList       commands_list;
+               int                  n_events;
+               DevEventList         events_list;
                                   }
                DevServerClassPart;
 
