@@ -1,6 +1,9 @@
-static char RcsId[] = "$Header: /segfs/dbase/res/svc/ndbm/RCS/main_svc.cpp,v 6.9 2000/03/15 17:07:48 taurel Rel goetz $";
+static char RcsId[] = "$Header: main_svc.cpp,v 6.10 2001/01/08 11:45:53 goetz Rel $";
+
+/* $Log:	main_svc.cpp,v $
+Revision 6.10  2001/01/08  11:45:53  11:45:53  goetz (Andy Goetz)
+added patch by B.Pedersen to support querying events
 
-/* $Log: main_svc.cpp,v $
  * Revision 6.9  2000/03/15 17:07:48  taurel
  * Change compilation variable from -solaris to sun
  *
@@ -497,6 +500,7 @@ db_setupprog_1(struct svc_req *rqstp,SVCXPRT *transp)
 		nam db_cmd_query_1_arg;
 		psdev_reg_x db_psdev_reg_1_arg;
 		arr1 db_psdev_unreg_1_arg;
+		nam db_event_query_1_arg;
 	} argument;
 	char *result;
 	xdrproc_t xdr_argument, xdr_result;
@@ -601,6 +605,12 @@ db_setupprog_1(struct svc_req *rqstp,SVCXPRT *transp)
 		xdr_result = (xdrproc_t)xdr_cmd_que;
 		local = (DbRpcLocalFunc) db_cmd_query_1_svc;
 		break;
+		/* event query */
+	case DB_EVENTQUERY:
+		xdr_argument = (xdrproc_t)xdr_nam;
+		xdr_result = (xdrproc_t)xdr_event_que;
+		local = (DbRpcLocalFunc) db_event_query_1_svc;
+		break;
 
 	case DB_PSDEV_REG:
 		xdr_argument = (xdrproc_t)xdr_psdev_reg_x;
