@@ -1,4 +1,4 @@
-static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/setacc_clnt.c,v 6.9 1999/07/08 15:44:27 goetz Rel goetz $";
+static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/setacc_clnt.c,v 6.12 2001/01/08 13:29:17 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -18,6 +18,15 @@ static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/setacc_clnt.c,v 6.
  Original   :   January 1991
 
  * $Log: setacc_clnt.c,v $
+ * Revision 6.12  2001/01/08 13:29:17  goetz
+ * added J.Quick's patch to support double arrays for resources
+ *
+ * Revision 6.11  2001/01/08 11:46:14  goetz
+ * added patch by B.Pedersen to support querying events
+ *
+ * Revision 6.10  2000/06/22 19:18:05  goetz
+ * added support for D_USHORT_TYPE and D_ULONG_TYPE
+ *
  * Revision 6.9  1999/07/08 15:44:27  goetz
  * added J.Quick's patch to fix reconnection bug on Linux
  *
@@ -580,6 +589,41 @@ cmd_que
 	return (&res);
 }
 
+/*event query function */
+event_que
+#if defined __STDC__ | defined __STDCPP__
+* db_event_query_1(nam *argp, CLIENT *clnt, long *perr)
+#else
+*db_event_query_1(argp, clnt, perr)
+	nam *argp;
+	CLIENT *clnt;
+	long *perr;
+#endif	/* __STDC__ */
+{
+	static event_que res;
+	enum clnt_stat clnt_stat;
+
+	memset((void *)&res, 0, sizeof(res));
+
+	clnt_stat = clnt_call(clnt, DB_EVENTQUERY, (xdrproc_t)xdr_nam, 
+	                      (caddr_t)argp, (xdrproc_t)xdr_event_que, 
+		              (caddr_t)&res, TIMEVAL(TimeOut));
+
+	if (clnt_stat != RPC_SUCCESS)
+	{
+		if (clnt_stat == RPC_TIMEDOUT)
+			*perr = DevErr_RPCTimedOut;
+		else if (clnt_stat == RPC_CANTENCODEARGS)
+			*perr = DbErr_CannotEncodeArguments;
+		else if (clnt_stat == RPC_CANTDECODERES)
+			*perr = DbErr_CannotDecodeResult;
+		else
+			*perr = DbErr_RPCreception;
+		return (NULL);
+	}
+	return (&res);
+}
+/*end event query */
 
 
 db_psdev_error
