@@ -1,4 +1,4 @@
-static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/update_cli.c,v 6.9 1999/07/08 15:44:27 goetz Rel goetz $";
+static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/update_cli.c,v 6.12 2001/01/08 13:29:17 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -17,6 +17,15 @@ static char RcsId[] = "@(#)$Header: /segfs/dbase/res/clnt/RCS/update_cli.c,v 6.9
 
 
  * $Log: update_cli.c,v $
+ * Revision 6.12  2001/01/08 13:29:17  goetz
+ * added J.Quick's patch to support double arrays for resources
+ *
+ * Revision 6.11  2001/01/08 11:46:14  goetz
+ * added patch by B.Pedersen to support querying events
+ *
+ * Revision 6.10  2000/06/22 19:18:05  goetz
+ * added support for D_USHORT_TYPE and D_ULONG_TYPE
+ *
  * Revision 6.9  1999/07/08 15:44:27  goetz
  * added J.Quick's patch to fix reconnection bug on Linux
  *
