@@ -13,15 +13,27 @@
  Original:	January 1991
 
 
- $Revision: 8.18 $
- $Date: 2000/11/12 13:24:02 $
+ $Revision: 8.20 $
+ $Date: 2001/01/08 13:11:53 $
 
  $Author: goetz $
 
  $Log:	API.h,v $
- * Revision 8.18  2000/11/12  13:24:02  13:24:02  goetz (Andy Goetz)
- * added dynamic error handling; improved TANGO error treatment
+ * Revision 8.20  2001/01/08  13:11:53  13:11:53  goetz (Andy Goetz)
+ * added patch by B.Pedersen to support querying events
  * 
+ Revision 8.31  2000/07/28 09:59:52  dserver
+ BP: added dev_query_event to get event parameters
+     -> new data struture  for event list in server
+        events have to be registered by the server,
+        similar to commands.
+
+ Revision 8.19  2000/12/11 12:06:39  goetz
+ fixed bugs with TANGO interface returning unsigned values and states
+
+ Revision 8.18  2000/11/12 13:24:02  goetz
+ added dynamic error handling; improved TANGO error treatment
+
  Revision 8.17  1900/09/26 13:36:28  goetz
  tango_dev_putget() and tango_dev_putget_raw() implement immediate reconnection
 
@@ -171,7 +183,7 @@
  */
 #ifdef _IDENT
 static char APIh[] =
-"@(#)$Header: API.h,v 8.18 2000/11/12 13:24:02 goetz Rel $";
+"@(#)$Header: API.h,v 8.20 2001/01/08 13:11:53 goetz Rel $";
 #endif /* _IDENT */
 
 /*
@@ -315,6 +327,22 @@ typedef struct {
 	DevCmdInfo 	*sequence;
 	} DevVarCmdArray;
 
+/*
+ * structures for a dev_event_query() call
+ */
+
+typedef struct {
+	long    event;
+	char    event_name [SHORT_NAME_SIZE];
+	char	*out_name;
+	long    out_type;
+	} DevEventInfo;
+
+typedef struct {
+	u_int          	length;
+	DevEventInfo 	*sequence;
+	} DevVarEventArray;
+
 
 /*
  * structures for a dev_inform() call
@@ -397,6 +425,9 @@ extern _DLLFunc long  dev_xdrfree
 extern _DLLFunc long  dev_cmd_query
 				PT_( (devserver ds, DevVarCmdArray *varcmdarr,
 				long *error) );
+extern _DLLFunc long  dev_event_query
+				PT_( (devserver ds, DevVarEventArray *vareventarr,
+				long *error) );
 extern _DLLFunc long  dev_inform
 				PT_( (devserver *clnt_handles, long num_devices,
 				DevInfo * *dev_info, long *error) );
