@@ -13,15 +13,27 @@
  Original:	June 1992
 
 
- $Revision: 8.18 $
- $Date: 2000/11/12 13:24:02 $
+ $Revision: 8.20 $
+ $Date: 2001/01/08 13:11:54 $
 
  $Author: goetz $
 
  $Log:	ApiP.h,v $
- * Revision 8.18  2000/11/12  13:24:02  13:24:02  goetz (Andy Goetz)
- * added dynamic error handling; improved TANGO error treatment
+ * Revision 8.20  2001/01/08  13:11:54  13:11:54  goetz (Andy Goetz)
+ * added patch by B.Pedersen to support querying events
  * 
+ Revision 8.31  2000/07/28 09:59:52  dserver
+ BP: added dev_query_event to get event parameters
+     -> new data struture  for event list in server
+        events have to be registered by the server,
+        similar to commands.
+
+ Revision 8.19  2000/12/11 12:06:40  goetz
+ fixed bugs with TANGO interface returning unsigned values and states
+
+ Revision 8.18  2000/11/12 13:24:02  goetz
+ added dynamic error handling; improved TANGO error treatment
+
  Revision 8.17  1900/09/26 13:36:28  goetz
  tango_dev_putget() and tango_dev_putget_raw() implement immediate reconnection
 
@@ -172,7 +184,7 @@
  */
 #ifdef _IDENT
 static char ApiPh[] =
-"@(#)$Header: ApiP.h,v 8.18 2000/11/12 13:24:02 goetz Rel $";
+"@(#)$Header: ApiP.h,v 8.20 2001/01/08 13:11:54 goetz Rel $";
 #endif /* _IDENT */
 
 
@@ -441,6 +453,11 @@ extern _DLLFunc _dev_free_out *  rpc_dev_free_4
 			PT_( (_dev_free_in *dev_free_in) );
 extern _DLLFunc _client_data *  rpc_dev_putget_4
 			PT_( (_server_data *server_data) );
+/*event query */
+extern _DLLFunc _dev_queryevent_out *  rpc_dev_event_query_4
+			PT_((_dev_query_in *dev_query_in));
+
+/*end event query*/
 extern _DLLFunc _client_data *  rpc_dev_put_4
 			PT_( (_server_data *server_data) );
 extern _DLLFunc _client_raw_data *  rpc_dev_putget_raw_4
@@ -594,7 +611,7 @@ long dev_error_push PT_( (char *error_string) );
 #define DEVSERVER_VERS ((u_long)1) /* The old version number !!!!! */
 #define API_VERSION    ((u_long)4) /* The new version of the library !!! */
 #define ASYNCH_API_VERSION ((u_long)5) /* Asynchronous call version for API_VERSION */
-
+#define RPC_DEV_EVENT_QUERY ((u_long)20)
 #define RPC_DEV_IMPORT ((u_long)1)
 #define RPC_DEV_FREE ((u_long)2)
 #define RPC_DEV_PUTGET ((u_long)3)
