@@ -11,8 +11,8 @@
 
  Original:      September 1993
 
- $Revision: 8.18 $
- $Date: 2000/11/12 13:24:02 $
+ $Revision: 8.20 $
+ $Date: 2001/01/08 13:11:54 $
 
  Copyright (c) 1990 by European Synchrotron Radiation Facility,
 		       Grenoble, France
@@ -117,6 +117,10 @@ long _DLLFunc sec_tcp_connection
 void _DLLFunc sec_free_tcp_connection
 			PT_( (devserver ds,server_connections *svr_conn));
 
+#ifdef _DevServer_h
+/* DevServerDevices is declared in DevServer.h
+ * so hopefully these functions are needed only for servers
+ */
 #ifndef __cplusplus
 /*
  * OIC version
@@ -154,6 +158,7 @@ extern "C" long _DLLFunc sec_svc_cmd
 extern "C" void _DLLFunc free_var_str_array
 			PT_( (DevVarStringArray *str_array) );
 #endif /* __cplusplus */
+#endif /* _DevServer_h */
 
 long _DLLFunc free_connection_id_vers3
 			PT_( (long connection_id, long *error) );
