@@ -1,5 +1,5 @@
 static char RcsId[]         = 
-"@(#)$Header: ds_prog_vers3.c,v 8.14 2000/06/22 14:50:33 goetz Rel $";
+"@(#)$Header: ds_prog_vers3.c,v 8.20 2001/01/08 13:14:50 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -15,12 +15,30 @@ static char RcsId[]         =
  Original   :	November 1994
 
 
- $Revision: 8.14 $
- $Date: 2000/06/22 14:50:33 $
+ $Revision: 8.20 $
+ $Date: 2001/01/08 13:14:50 $
  $Author: goetz $
 
  $Log:	ds_prog_vers3.c,v $
- * Revision 8.14  2000/06/22  14:50:33  14:50:33  goetz (Andrew GOETZ)
+ * Revision 8.20  2001/01/08  13:14:50  13:14:50  goetz (Andy Goetz)
+ * added patch by B.Pedersen to support querying events
+ * 
+ Revision 8.19  2000/12/11 12:06:44  goetz
+ fixed bugs with TANGO interface returning unsigned values and states
+
+ Revision 8.18  2000/11/12 13:24:03  goetz
+ added dynamic error handling; improved TANGO error treatment
+
+ Revision 8.17  1900/09/26 13:36:34  goetz
+ tango_dev_putget() and tango_dev_putget_raw() implement immediate reconnection
+
+ * Revision 8.16  2000/09/25  14:50:16  14:50:16  goetz (Andy Goetz)
+ * tango_api implements TANGO_HOST, stateless import and reimport
+ * 
+ * Revision 8.15  20/0./7.  1.:6.:9.  1.:6.:9.  goetz (Andy Goetz)
+ * changed from tango database to host mysql, added support for float and double arrays
+ * 
+ * Revision 8.14  20/0./6.  2.:4.:0.  2.:4.:0.  goetz (Andy Goetz)
  * fixed bug in dev_event_listen() which caused server to crash
  * 
  Revision 8.13  2000/06/02 21:56:49  goetz
