@@ -1,4 +1,4 @@
-static char RcsId[] = "@(#)$Header: event_api.c,v 8.18 2000/11/12 13:24:01 goetz Rel $";
+static char RcsId[] = "@(#)$Header: event_api.c,v 8.20 2001/01/08 12:05:09 goetz Rel $";
 /*+*******************************************************************
 
  File       :	event_api.c
@@ -33,15 +33,27 @@ static char RcsId[] = "@(#)$Header: event_api.c,v 8.18 2000/11/12 13:24:01 goetz
 
  Original   :	April 1999
 
- $Revision: 8.18 $
- $Date: 2000/11/12 13:24:01 $
+ $Revision: 8.20 $
+ $Date: 2001/01/08 12:05:09 $
 
  $Author: goetz $
 
  $Log:	event_api.c,v $
- * Revision 8.18  2000/11/12  13:24:01  13:24:01  goetz (Andy Goetz)
- * added dynamic error handling; improved TANGO error treatment
+ * Revision 8.20  2001/01/08  12:05:09  12:05:09  goetz (Andy Goetz)
+ * added patch by B.Pedersen to support querying events
  * 
+ Revision 8.31  2000/07/28 09:59:53  dserver
+ BP: added dev_query_event to get event parameters
+     -> new data struture  for event list in server
+        events have to be registered by the server,
+        similar to commands.
+
+ Revision 8.19  2000/12/11 12:06:38  goetz
+ fixed bugs with TANGO interface returning unsigned values and states
+
+ Revision 8.18  2000/11/12 13:24:01  goetz
+ added dynamic error handling; improved TANGO error treatment
+
  Revision 8.17  1900/09/26 13:36:26  goetz
  tango_dev_putget() and tango_dev_putget_raw() implement immediate reconnection
 
@@ -1120,3 +1132,371 @@ _dev_free_out* _DLLFunc rpc_event_unlisten_5 (_server_data *server_data)
 
 	return(&dev_free_out);
 }
+
+static db_resource   res_tab [] = {
+	{(char *)"Out_Type", D_STRING_TYPE, NULL},
+};
+
+static long get_event_string PT_( (devserver ds, long event, char *event_str, long *error) );
+
+/*+**********************************************************************
+ Function   : 	extern long dev_event_query()
+
+ Description:	Returns a sequence of structures containig all
+		available events, their names, their input and
+		output data types, and type describtions for one
+		device.
+            :	Events and data types are read from the command
+		list in the device server by calling 
+		RPC_DEV_EVENT_QUERY.
+            :	Event names are read from the command name list,
+		defined in the database (EVENT/team/server/event)
+            :	Data type describtions have to be specified as 
+		CLASS resources as:
+            :		CLASS/class_name/event_name/OUT_TYPE:
+
+ Arg(s) In  :	ds - client handle for the associated device.
+
+ Arg(s) Out :	vareventarr - sequence of DevEventInfo structures.
+		error     - Will contain an appropriate error code if the
+			    corresponding call returns a non-zero value.
+
+ Return(s)  :	DS_OK or DS_NOTOK
+***********************************************************************-*/
+
+long _DLLFunc dev_event_query (devserver ds, DevVarEventArray *vareventarr, long *error)
+{
+	_dev_query_in	dev_query_in;
+	_dev_queryevent_out	dev_query_out;
+	enum clnt_stat  clnt_stat;
+	char		class_name[SHORT_NAME_SIZE];
+	char		event_name[SHORT_NAME_SIZE];
+	long		length;
+	long		ret_stat;
+	char		res_path [LONG_NAME_SIZE];
+	int		i;
+	u_int 		res_tab_size = sizeof(res_tab) / 
+	    sizeof(db_resource);
+	long		status;
+
+	*error = 0;
+#ifdef EBUG
+	dev_printdebug (DBG_TRACE | DBG_API,
+	    "\ndev_event_query() : entering routine\n");
+#endif /* EBUG */
+
+#ifdef TANGO
+	if (ds->rpc_protocol == D_IIOP)
+	{
+		*error = DevErr_CommandNotImplemented;
+		status = DS_NOTOK;
+		return(status);
+	}
+#endif /* TANGO */
+	/*
+         * Verify the RPC connection.
+         */
+
+	if ( dev_rpc_connection (ds, error)  == DS_NOTOK )
+	{
+		return (DS_NOTOK);
+	}
+
+
+	/*
+         *  fill in data transfer structures dev_query_in
+         *  and dev_query_out.
+         */
+
+	dev_query_in.ds_id = ds->ds_id;
+
+	dev_query_in.var_argument.length   = 0;
+	dev_query_in.var_argument.sequence = NULL;
+
+
+	/*
+ *  Call the rpc entry point RPC_DEV_EVENT_QUERY at the specified device server.
+ */
+
+	memset ((char *)&dev_query_out, 0, sizeof (dev_query_out));
+
+	/*
+	 * Query a device with the current version number >1.
+   	 */
+	if ( ds->vers_number > DEVSERVER_VERS)
+	{
+		clnt_stat = clnt_call (ds->clnt, RPC_DEV_EVENT_QUERY,
+		    (xdrproc_t)xdr__dev_query_in,  (caddr_t) &dev_query_in,
+		    (xdrproc_t)xdr__dev_queryevent_out, (caddr_t) &dev_query_out, TIMEVAL(timeout));
+	}
+	else
+	{
+		/*
+	    * Query a device from an old version server.
+	     THIS is not supported for old servers
+	    */
+		    return (DS_NOTOK);
+	}
+
+
+	/*
+         * Check for errors on the RPC connection.
+         */
+
+	if ( dev_rpc_error (ds, clnt_stat, error) == DS_NOTOK )
+	{
+		return (DS_NOTOK);
+	}
+
+	/*
+         * Free the variable arguments in the dev_query_out
+         * structure, coming from the server.
+         */
+
+	xdr_free ((xdrproc_t)xdr_DevVarArgumentArray,
+	    (char *)&(dev_query_out.var_argument));
+
+
+	/*
+ * Allocate memory for a sequence of DevEventInfo structures
+ * returned with vareventarr.
+ */
+
+	vareventarr->length   = dev_query_out.length;
+	vareventarr->sequence = (DevEventInfo *) malloc
+	    (vareventarr->length * sizeof (DevEventInfo));
+	if ( vareventarr->sequence == NULL )
+	{
+		*error  = DevErr_InsufficientMemory;
+		return (-1);
+	}
+	memset ((char *)vareventarr->sequence, 0,
+	    (vareventarr->length * sizeof (DevEventInfo)));
+
+	/*
+ * Now get command and types name strings for the returned
+ * command sequence. Command names are retrieved from the
+ * global command-name-list and name strings for the data types
+ * are searched in the resource CLASS table of the object class.
+ * 
+ * Undefined names will be initialised with NULL.
+ */
+
+	for ( i=0; (u_long)i<vareventarr->length; i++ )
+	{
+		/*
+	    * initialise vareventarr->sequence[i] with command and
+	    * argument types, returned with dev_query_out from the
+	    * device servers command list.
+	    */
+
+		vareventarr->sequence[i].event      = dev_query_out.sequence[i].event;
+		vareventarr->sequence[i].out_type = dev_query_out.sequence[i].out_type;
+
+		/*
+	    * get command name string from the resource database
+	    */
+
+		if ( (ret_stat = get_event_string (ds, vareventarr->sequence[i].event, 
+		    vareventarr->sequence[i].event_name, 
+		    error )) == DS_NOTOK )
+		{
+			/*
+	       * An error will be only returned if the database
+	       * access fails.
+	       */
+			return (DS_NOTOK);
+		}
+
+
+		/*
+	    *  Check wether command name was found.
+	    *  If the name was not found, get_event_string() returns
+	    *  DS_WARNING.
+	    */
+
+		if ( ret_stat != DS_WARNING )
+		{
+			/*
+	       * Limit the class_name and the command_name
+	       * strings to 19 characters. This is the limit
+	       * of the static database name fields.
+	       */
+
+			length = strlen (dev_query_out.class_name);
+			if ( length > MAX_RESOURCE_FIELD_LENGTH )
+				length = MAX_RESOURCE_FIELD_LENGTH;
+			strncpy (class_name, dev_query_out.class_name, 
+			    MAX_RESOURCE_FIELD_LENGTH);
+			class_name[(_Int)length] = '\0';
+
+			length = strlen (vareventarr->sequence[i].event_name);
+			if ( length > MAX_RESOURCE_FIELD_LENGTH )
+				length = MAX_RESOURCE_FIELD_LENGTH;
+			strncpy (event_name, vareventarr->sequence[i].event_name,
+			    MAX_RESOURCE_FIELD_LENGTH);
+			event_name[(_Int)length] = '\0';
+
+/*
+ *  setup resource path to read information about
+ *  data types from the CLASS resource table.
+ *
+ * but first check to see whether the device belongs to another
+ * nethost domain i.e. i_nethost != 0
+ */
+
+			if (ds->i_nethost > -1)
+			{
+				sprintf(res_path, "//%s/CLASS/%s/%s",
+				   get_nethost_by_index(ds->i_nethost, error),
+				   class_name, event_name);
+			}
+/*
+ * use default nethost
+ */
+			else
+			{
+				sprintf (res_path, "CLASS/%s/%s", 
+				   class_name, event_name);
+			}
+
+			/*
+	       *  read CLASS resources from database
+	       */
+
+			res_tab[0].resource_adr = &(vareventarr->sequence[i].out_name);
+
+			if (db_getresource (res_path, res_tab, res_tab_size, error) < 0)
+			{
+				return (-1);
+			}
+		}
+	}
+
+	/*
+	 *  free dev_query_out 
+	 */
+
+	xdr_free ((xdrproc_t)xdr__dev_queryevent_out,
+	    (char *)&dev_query_out);
+
+	/*
+ * Return error code and status from device server.
+ */
+
+	*error = dev_query_out.error;
+	return (dev_query_out.status);
+}
+
+
+/*+**********************************************************************
+ Function   :	static long get_event_string()
+
+ Description:   Read the event name as a string from the
+		resource database.
+		The resource name is:
+		EVENT/team_no/server_no/event_ident:
+		DS_WARNING is returned, if the function was
+		executed correctly, but no event name
+		string was found in the database.
+
+ Arg(s) In  :   long event      - error number
+
+ Arg(s) Out :   char *event_str - command name as a string.
+		long *error   - Will contain an appropriate error
+			        code if the corresponding call
+		    	        returns a non-zero value.
+
+ Return(s)  :   DS_OK or DS_NOTOK or DS_WARNING
+***********************************************************************-*/
+
+static long get_event_string (devserver ds, long event, char *event_str, long *error)
+{
+	char		res_path[LONG_NAME_SIZE];
+	char		res_name[SHORT_NAME_SIZE];
+	char		*ret_str = NULL;
+	db_resource 	res_tab;
+	unsigned long 	event_number_mask = 0x3ffff;
+	unsigned short 	team;
+	unsigned short 	server;
+	unsigned short 	events_ident;
+
+#ifdef EBUG
+	dev_printdebug (DBG_TRACE | DBG_API,
+	    "\nget_event_string() : entering routine\n");
+#endif /* EBUG */
+
+	*error = 0;
+
+	/*
+ * Decode the command nuber into the fields:
+ * team, server and events_ident.
+ */
+	team   = (_Int)(event >> DS_TEAM_SHIFT);
+	team   = team & DS_TEAM_MASK;
+	server = (_Int)(event >> DS_IDENT_SHIFT);
+	server = server & DS_IDENT_MASK;
+	events_ident = (_Int)(event & event_number_mask);
+
+	/*
+ * Create the resource path and the resource structure.
+ *
+ * first check to see whether the device belongs to another
+ * nethost domain i.e. i_nethost != 0
+ */
+
+	if (ds->i_nethost > 0)
+	{
+		sprintf(res_path, "//%s/EVENTS/%d/%d", 
+		   get_nethost_by_index(ds->i_nethost, error),
+		   team, server);
+	}
+/*
+ * use default nethost
+ */
+	else
+	{
+		sprintf(res_path, "EVENTS/%d/%d", team, server);
+	}
+
+	sprintf (res_name, "%d", events_ident);
+#ifdef EBUG
+	dev_printdebug (DBG_API,
+	    "get_events_string() : res_path = %s\n", res_path);
+	dev_printdebug (DBG_API,
+	    "get_events_string() : res_name = %s\n", res_name);
+#endif /* EBUG */
+
+	res_tab.resource_name = res_name;
+	res_tab.resource_type = D_STRING_TYPE;
+	res_tab.resource_adr  = &ret_str;
+
+	/*
+ * Read the command name string from the database.
+ */
+
+	if (db_getresource (res_path, &res_tab, 1, error) == DS_NOTOK)
+	{
+#ifdef EBUG
+		dev_printdebug (DBG_API | DBG_ERROR,
+		    "get_event_string() : db_getresource failed with error %d\n", *error);
+#endif /* EBUG */
+
+		return (DS_NOTOK);
+	}
+
+/*
+ * If the variable ret_str is still NULL, no resource value was found
+ * in the database, but the function was executed without error.
+ * In this case return the value DS_WARNING.
+ */
+	if ( ret_str == NULL )
+	{
+		return (DS_WARNING);
+	}
+
+	sprintf (event_str, "%s", ret_str);
+	free (ret_str);
+	return (DS_OK);
+}
+
