@@ -1,5 +1,5 @@
 static char RcsId[] = 
-"@(#)$Header: gen_api.c,v 8.18 2000/11/12 13:24:01 goetz Rel $";
+"@(#)$Header: gen_api.c,v 8.20 2001/01/08 12:05:09 goetz Rel $";
 /*+*******************************************************************
 
  File       :	gen_api.c
@@ -13,15 +13,21 @@ static char RcsId[] =
 
  Original   :	January 1991
 
- $Revision: 8.18 $
- $Date: 2000/11/12 13:24:01 $
+ $Revision: 8.20 $
+ $Date: 2001/01/08 12:05:09 $
 
  $Author: goetz $
 
  $Log:	gen_api.c,v $
- * Revision 8.18  2000/11/12  13:24:01  13:24:01  goetz (Andy Goetz)
- * added dynamic error handling; improved TANGO error treatment
+ * Revision 8.20  2001/01/08  12:05:09  12:05:09  goetz (Andy Goetz)
+ * added patch by B.Pedersen to support querying events
  * 
+ Revision 8.19  2000/12/11 12:06:32  goetz
+ fixed bugs with TANGO interface returning unsigned values and states
+
+ Revision 8.18  2000/11/12 13:24:01  goetz
+ added dynamic error handling; improved TANGO error treatment
+
  Revision 8.17  1900/09/26 13:36:18  goetz
  tango_dev_putget() and tango_dev_putget_raw() implement immediate reconnection
 
@@ -1941,8 +1947,8 @@ static char *get_error_string (long error)
 
 	time_t		sec;
 	char		*time_stamp;
-	static char	*no_error_mess="No error message stored in the database for negative errors\n";
-	static char	*db_error_mess="Failed to get error message from database\n";
+	static char	*no_error_mess=(char*)"No error message stored in the database for negative errors\n";
+	static char	*db_error_mess=(char*)"Failed to get error message from database\n";
 
 
 #ifdef EBUG
