@@ -1,4 +1,4 @@
-static char RcsId[] = "@(#)$Header: tango_api.cpp,v 8.18 2000/11/12 13:24:01 goetz Rel $";
+static char RcsId[] = "@(#)$Header: tango_api.cpp,v 8.20 2001/01/08 12:08:26 goetz Exp $";
 /*+*******************************************************************
 
  File       :	tango_api.c
@@ -17,15 +17,21 @@ static char RcsId[] = "@(#)$Header: tango_api.cpp,v 8.18 2000/11/12 13:24:01 goe
 
  Original   :	December 1999
 
- $Revision: 8.18 $
- $Date: 2000/11/12 13:24:01 $
+ $Revision: 8.20 $
+ $Date: 2001/01/08 12:08:26 $
 
  $Author: goetz $
 
  $Log:	tango_api.cpp,v $
-// Revision 8.18  2000/11/12  13:24:01  13:24:01  goetz (Andy Goetz)
-// added dynamic error handling; improved TANGO error treatment
+// Revision 8.20  2001/01/08  12:08:26  12:08:26  goetz (Andy Goetz)
+// added patch by B.Pedersen to support querying events
 // 
+ Revision 8.19  2000/12/11 12:06:38  goetz
+ fixed bugs with TANGO interface returning unsigned values and states
+
+ Revision 8.18  2000/11/12 13:24:01  goetz
+ added dynamic error handling; improved TANGO error treatment
+
  Revision 8.17  1900/09/26 13:36:27  goetz
  tango_dev_putget() and tango_dev_putget_raw() implement immediate reconnection
 
@@ -99,8 +105,8 @@ typedef struct _tango_device {
 	Tango_Device_var object;} _tango_device;
 static vector<_tango_device> tango_device;
 static long n_tango_device=0;
-static string tango_host;
 static int tango_port=10000;
+static char *tango_host_c_str=NULL;
 
 /*
  * symbols used by TACO/TANGO interface
@@ -189,7 +195,6 @@ long tango_dev_import(char *dev_name, long access, devserver *ds_ptr, long *erro
 		try
 		{
 			char *tango_host_env_c_str;
-			char tango_host_c_str[256];
 
 			tango_host_env_c_str = getenv("TANGO_HOST");
 			if (tango_host_env_c_str == NULL)
@@ -198,6 +203,7 @@ long tango_dev_import(char *dev_name, long access, devserver *ds_ptr, long *erro
 				return(DS_NOTOK);
 			}
 			string tango_host_env(tango_host_env_c_str);
+			string tango_host;
 			string::size_type separator;
 			
 			separator = tango_host_env.find(":");
@@ -207,6 +213,7 @@ long tango_dev_import(char *dev_name, long access, devserver *ds_ptr, long *erro
 			}
 			tango_host = tango_host_env.substr(0,separator);
 			
+			tango_host_c_str = (char*)malloc(strlen(tango_host.c_str())+1);
 			sprintf(tango_host_c_str,"%s",tango_host.c_str());
 			tango_db_import("database",tango_host_c_str,
 					 tango_port,error);
@@ -359,9 +366,6 @@ long tango_dev_reimport(devserver ds, long *error)
 	{
 		try
 		{
-			char tango_host_c_str[256];
-			sprintf(tango_host_c_str,"%s",tango_host.c_str());
-
 			tango_db_import("database",tango_host_c_str,
 					 tango_port,error);
         	}
@@ -829,10 +833,8 @@ static CORBA_Any tango_argin_to_any(long argin_type, long tango_type, void *argi
 		}
 
 		case D_SHORT_TYPE :
-		case D_USHORT_TYPE :
 		{
-			if ((tango_type != Tango_DEV_SHORT) &&
-			    (tango_type != Tango_DEV_USHORT))
+			if (tango_type != Tango_DEV_SHORT)
 			{
 				throw_exception((const char*)"TANGO argin type not Tango_DEV_SHORT ", 
 				                (const char *)"tango_argin_to_any()",
@@ -845,11 +847,25 @@ static CORBA_Any tango_argin_to_any(long argin_type, long tango_type, void *argi
 			break;
 		}
 			
-		case D_LONG_TYPE :
-		case D_ULONG_TYPE :
+
+		case D_USHORT_TYPE :
 		{
-			if ((tango_type != Tango_DEV_LONG) &&
-			    (tango_type != Tango_DEV_ULONG))
+			if (tango_type != Tango_DEV_USHORT)
+			{
+				throw_exception((const char*)"TANGO argin type not Tango_DEV_USHORT ", 
+				                (const char *)"tango_argin_to_any()",
+				                DevErr_IncompatibleCmdArgumentTypes ,
+						Tango_APILIB);
+			}
+			unsigned short *argin_short;
+			argin_short = (unsigned short*)argin;
+			send <<= *argin_short;
+			break;
+		}
+			
+		case D_LONG_TYPE :
+		{
+			if (tango_type != Tango_DEV_LONG)
 			{
 				throw_exception((const char*)"TANGO argin type not Tango_DEV_LONG ", 
 				                (const char *)"tango_argin_to_any()",
@@ -862,6 +878,21 @@ static CORBA_Any tango_argin_to_any(long argin_type, long tango_type, void *argi
 			break;
 		}
 			
+		case D_ULONG_TYPE :
+		{
+			if (tango_type != Tango_DEV_ULONG)
+			{
+				throw_exception((const char*)"TANGO argin type not Tango_DEV_ULONG ", 
+				                (const char *)"tango_argin_to_any()",
+				                DevErr_IncompatibleCmdArgumentTypes ,
+						Tango_APILIB);
+			}
+			unsigned long *argin_ulong;
+			argin_ulong = (unsigned long*)argin;
+			send <<= *argin_ulong;
+			break;
+		}
+			
 		case D_FLOAT_TYPE :
 		{
 			if (tango_type != Tango_DEV_FLOAT)
@@ -930,10 +961,8 @@ static CORBA_Any tango_argin_to_any(long argin_type, long tango_type, void *argi
 		}
 			
 		case D_VAR_SHORTARR :
-		case D_VAR_USHORTARR :
 		{
-			if ((tango_type != Tango_DEVVAR_SHORTARRAY) &&
-			    (tango_type != Tango_DEVVAR_USHORTARRAY))
+			if (tango_type != Tango_DEVVAR_SHORTARRAY)
 			{
 				throw_exception((const char*)"TANGO argin type not Tango_DEVVAR_SHORTARRAY ", 
 				                (const char *)"tango_argin_to_any()",
@@ -952,11 +981,30 @@ static CORBA_Any tango_argin_to_any(long argin_type, long tango_type, void *argi
 			break;
 		}
 			
-		case D_VAR_LONGARR :
-		case D_VAR_ULONGARR :
+		case D_VAR_USHORTARR :
 		{
-			if ((tango_type != Tango_DEVVAR_LONGARRAY) &&
-			    (tango_type != Tango_DEVVAR_ULONGARRAY))
+			if (tango_type != Tango_DEVVAR_USHORTARRAY)
+			{
+				throw_exception((const char*)"TANGO argin type not Tango_DEVVAR_USHORTARRAY ", 
+				                (const char *)"tango_argin_to_any()",
+				                DevErr_IncompatibleCmdArgumentTypes ,
+						Tango_APILIB);
+			}
+			DevVarUShortArray *argin_vusha;
+			argin_vusha = (DevVarUShortArray*)argin;
+			Tango_DevVarUShortArray *tango_vusha = new Tango_DevVarUShortArray;
+			tango_vusha->length(argin_vusha->length);
+			for (long i=0; i<argin_vusha->length; i++)
+			{
+				(*tango_vusha)[i] = argin_vusha->sequence[i];
+			}
+			send <<= tango_vusha;
+			break;
+		}
+			
+		case D_VAR_LONGARR :
+		{
+			if (tango_type != Tango_DEVVAR_LONGARRAY)
 			{
 				throw_exception((const char*)"TANGO argin type not Tango_DEVVAR_LONGARRAY ", 
 				                (const char *)"tango_argin_to_any()",
@@ -975,6 +1023,27 @@ static CORBA_Any tango_argin_to_any(long argin_type, long tango_type, void *argi
 			break;
 		}
 			
+		case D_VAR_ULONGARR :
+		{
+			if (tango_type != Tango_DEVVAR_ULONGARRAY)
+			{
+				throw_exception((const char*)"TANGO argin type not Tango_DEVVAR_ULONGARRAY ", 
+				                (const char *)"tango_argin_to_any()",
+				                DevErr_IncompatibleCmdArgumentTypes ,
+						Tango_APILIB);
+			}
+			DevVarULongArray *argin_vula;
+			argin_vula = (DevVarULongArray*)argin;
+			Tango_DevVarULongArray *tango_vula = new Tango_DevVarULongArray;
+			tango_vula->length(argin_vula->length);
+			for (long i=0; i<argin_vula->length; i++)
+			{
+				(*tango_vula)[i] = argin_vula->sequence[i];
+			}
+			send <<= tango_vula;
+			break;
+		}
+			
 		case D_VAR_FLOATARR :
 		{
 			if (tango_type != Tango_DEVVAR_FLOATARRAY)
@@ -1066,13 +1135,12 @@ static void tango_any_to_argout(long argout_type, long tango_type, CORBA_Any rec
 		}
 
 		case D_SHORT_TYPE :
-		case D_USHORT_TYPE :
 		{
 			short tango_short;
 			short *argout_short;
+			Tango_DevState tango_state;
 
 			if ((tango_type != Tango_DEV_SHORT) &&
-			    (tango_type != Tango_DEV_USHORT) &&
 			    (tango_type != Tango_DEV_STATE))
 			{
 				throw_exception((const char*)"tango argout type is not Tango_DEV_SHORT", 
@@ -1080,14 +1148,39 @@ static void tango_any_to_argout(long argout_type, long tango_type, CORBA_Any rec
 				                DevErr_IncompatibleCmdArgumentTypes ,
 				                Tango_APILIB);
 			}
-			received >>= tango_short;
 			argout_short = (short*)argout;
-			*argout_short = tango_short;
+			if (tango_type == Tango_DEV_SHORT)
+			{
+				received >>= tango_short;
+				*argout_short = tango_short;
+			}
+			if (tango_type == Tango_DEV_STATE)
+			{
+				received >>= tango_state;
+				*argout_short = tango_state;
+			}
+			break;
+		}
+
+		case D_USHORT_TYPE :
+		{
+			unsigned short tango_ushort;
+			unsigned short *argout_ushort;
+
+			if (tango_type != Tango_DEV_USHORT)
+			{
+				throw_exception((const char*)"tango argout type is not Tango_DEV_USHORT", 
+				                (const char *)"tango_any_to_argout()",
+				                DevErr_IncompatibleCmdArgumentTypes ,
+				                Tango_APILIB);
+			}
+			received >>= tango_ushort;
+			argout_ushort = (unsigned short*)argout;
+			*argout_ushort = tango_ushort;
 			break;
 		}
 
 		case D_LONG_TYPE :
-		case D_ULONG_TYPE :
 		{
 			long tango_long;
 			long *argout_long;
@@ -1105,6 +1198,24 @@ static void tango_any_to_argout(long argout_type, long tango_type, CORBA_Any rec
 			break;
 		}
 
+		case D_ULONG_TYPE :
+		{
+			unsigned long tango_ulong;
+			unsigned long *argout_ulong;
+
+			if (tango_type != Tango_DEV_ULONG)
+			{
+				throw_exception((const char*)"tango argout type is not Tango_DEV_ULONG", 
+				                (const char *)"tango_any_to_argout()",
+				                DevErr_IncompatibleCmdArgumentTypes ,
+				                Tango_APILIB);
+			}
+			received >>= tango_ulong;
+			argout_ulong = (unsigned long*)argout;
+			*argout_ulong = tango_ulong;
+			break;
+		}
+
 		case D_FLOAT_TYPE :
 		{
 			float tango_float;
@@ -1188,13 +1299,11 @@ static void tango_any_to_argout(long argout_type, long tango_type, CORBA_Any rec
 		}
 
 		case D_VAR_SHORTARR :
-		case D_VAR_USHORTARR :
 		{
 			DevVarShortArray *argout_vsha;
 			Tango_DevVarShortArray *tango_vsha;
 
-			if ((tango_type != Tango_DEVVAR_SHORTARRAY) &&
-			    (tango_type != Tango_DEVVAR_USHORTARRAY))
+			if (tango_type != Tango_DEVVAR_SHORTARRAY)
 			{
 				throw_exception((const char*)"tango argout type is not Tango_DEVVAR_SHORTARRAY", 
 				                (const char *)"tango_any_to_argout()",
@@ -1215,8 +1324,33 @@ static void tango_any_to_argout(long argout_type, long tango_type, CORBA_Any rec
 			break;
 		}
 
+		case D_VAR_USHORTARR :
+		{
+			DevVarUShortArray *argout_vusha;
+			Tango_DevVarUShortArray *tango_vusha;
+
+			if (tango_type != Tango_DEVVAR_USHORTARRAY)
+			{
+				throw_exception((const char*)"tango argout type is not Tango_DEVVAR_USHORTARRAY", 
+				                (const char *)"tango_any_to_argout()",
+				                DevErr_IncompatibleCmdArgumentTypes ,
+				                Tango_APILIB);
+			}
+			received >>= tango_vusha;
+			argout_vusha = (DevVarUShortArray*)argout;
+			if (argout_vusha->sequence == NULL)
+			{
+				argout_vusha->sequence = (unsigned short*)malloc(tango_vusha->length()*sizeof(unsigned short));
+			}
+			argout_vusha->length = tango_vusha->length();
+			for (long i=0; i< tango_vusha->length(); i++)
+			{
+				argout_vusha->sequence[i] = (*tango_vusha)[i];
+			}
+			break;
+		}
+
 		case D_VAR_LONGARR :
-		case D_VAR_ULONGARR :
 		{
 			DevVarLongArray *argout_vla;
 			Tango_DevVarLongArray *tango_vla;
@@ -1243,6 +1377,32 @@ static void tango_any_to_argout(long argout_type, long tango_type, CORBA_Any rec
 			break;
 		}
 
+		case D_VAR_ULONGARR :
+		{
+			DevVarULongArray *argout_vula;
+			Tango_DevVarULongArray *tango_vula;
+
+			if (tango_type != Tango_DEVVAR_ULONGARRAY)
+			{
+				throw_exception((const char*)"tango argout type is not Tango_DEVVAR_ULONGARRAY", 
+				                (const char *)"tango_any_to_argout()",
+				                DevErr_IncompatibleCmdArgumentTypes ,
+				                Tango_APILIB);
+			}
+			received >>= tango_vula;
+			argout_vula = (DevVarULongArray*)argout;
+			if (argout_vula->sequence == NULL)
+			{
+				argout_vula->sequence = (unsigned long*)malloc(tango_vula->length()*sizeof(unsigned long));
+			}
+			argout_vula->length = tango_vula->length();
+			for (long i=0; i< tango_vula->length(); i++)
+			{
+				argout_vula->sequence[i] = (*tango_vula)[i];
+			}
+			break;
+		}
+
 		case D_VAR_FLOATARR :
 		{
 			DevVarFloatArray *argout_vfa;
@@ -1359,13 +1519,12 @@ static void tango_any_to_argout_raw(long argout_type, long tango_type, CORBA_Any
 		}
 
 		case D_SHORT_TYPE :
-		case D_USHORT_TYPE :
 		{
 			short tango_short;
+			Tango_DevState tango_state;
 			short taco_short;
 
 			if ((tango_type != Tango_DEV_SHORT) &&
-			    (tango_type != Tango_DEV_USHORT) &&
 			    (tango_type != Tango_DEV_STATE))
 			{
 				throw_exception((const char*)"tango argout type is not Tango_DEV_SHORT", 
@@ -1373,8 +1532,16 @@ static void tango_any_to_argout_raw(long argout_type, long tango_type, CORBA_Any
 				                DevErr_IncompatibleCmdArgumentTypes ,
 				                Tango_APILIB);
 			}
-			received >>= tango_short;
-			taco_short = tango_short;
+			if (tango_type == Tango_DEV_SHORT)
+			{
+				received >>= tango_short;
+				taco_short = tango_short;
+			}
+			else
+			{
+				received >>= tango_state;
+				taco_short = tango_state;
+			}
 			dc_datacmd.argout_type = argout_type;
 			dc_datacmd.argout = &taco_short;
 			status = dc_dataconvert(&dc_datacmd, 1, &dc_error);
@@ -1382,9 +1549,30 @@ static void tango_any_to_argout_raw(long argout_type, long tango_type, CORBA_Any
                         taco_opaque->sequence = dc_datacmd.sequence;
 			break;
 		}
+		 
+		case D_USHORT_TYPE :
+		{
+			unsigned short tango_ushort;
+			unsigned short taco_ushort;
 
+			if (tango_type != Tango_DEV_USHORT)
+			{
+				throw_exception((const char*)"tango argout type is not Tango_DEV_USHORT", 
+				                (const char *)"tango_any_to_argout_raw()",
+				                DevErr_IncompatibleCmdArgumentTypes ,
+				                Tango_APILIB);
+			}
+			received >>= tango_ushort;
+			taco_ushort = tango_ushort;
+			dc_datacmd.argout_type = argout_type;
+			dc_datacmd.argout = &taco_ushort;
+			status = dc_dataconvert(&dc_datacmd, 1, &dc_error);
+                        taco_opaque->length = dc_datacmd.length;
+                        taco_opaque->sequence = dc_datacmd.sequence;
+			break;
+		}
+		 
 		case D_LONG_TYPE :
-		case D_ULONG_TYPE :
 		{
 			long tango_long;
 			long taco_long;
@@ -1406,6 +1594,28 @@ static void tango_any_to_argout_raw(long argout_type, long tango_type, CORBA_Any
 			break;
 		}
 
+		case D_ULONG_TYPE :
+		{
+			unsigned long tango_ulong;
+			unsigned long taco_ulong;
+
+			if (tango_type != Tango_DEV_ULONG)
+			{
+				throw_exception((const char*)"tango argout type is not Tango_DEV_ULONG", 
+				                (const char *)"tango_any_to_argout_raw()",
+				                DevErr_IncompatibleCmdArgumentTypes ,
+				                Tango_APILIB);
+			}
+			received >>= tango_ulong;
+			taco_ulong = tango_ulong;
+			dc_datacmd.argout_type = argout_type;
+			dc_datacmd.argout = &taco_ulong;
+			status = dc_dataconvert(&dc_datacmd, 1, &dc_error);
+                        taco_opaque->length = dc_datacmd.length;
+                        taco_opaque->sequence = dc_datacmd.sequence;
+			break;
+		}
+
 		case D_FLOAT_TYPE :
 		{
 			float tango_float;
@@ -1509,13 +1719,11 @@ static void tango_any_to_argout_raw(long argout_type, long tango_type, CORBA_Any
 		}
 
 		case D_VAR_SHORTARR :
-		case D_VAR_USHORTARR :
 		{
 			DevVarShortArray taco_vsha;
 			Tango_DevVarShortArray *tango_vsha;
 
-			if ((tango_type != Tango_DEVVAR_SHORTARRAY) &&
-			    (tango_type != Tango_DEVVAR_USHORTARRAY))
+			if (tango_type != Tango_DEVVAR_SHORTARRAY)
 			{
 				throw_exception((const char*)"tango argout type is not Tango_DEVVAR_SHORTARRAY", 
 				                (const char *)"tango_any_to_argout_raw()",
@@ -1538,14 +1746,40 @@ static void tango_any_to_argout_raw(long argout_type, long tango_type, CORBA_Any
 			break;
 		}
 
+		case D_VAR_USHORTARR :
+		{
+			DevVarUShortArray taco_vusha;
+			Tango_DevVarUShortArray *tango_vusha;
+
+			if (tango_type != Tango_DEVVAR_USHORTARRAY)
+			{
+				throw_exception((const char*)"tango argout type is not Tango_DEVVAR_USHORTARRAY", 
+				                (const char *)"tango_any_to_argout_raw()",
+				                DevErr_IncompatibleCmdArgumentTypes ,
+				                Tango_APILIB);
+			}
+			received >>= tango_vusha;
+			taco_vusha.sequence = (unsigned short*)malloc(tango_vusha->length()*sizeof(unsigned short));
+			taco_vusha.length = tango_vusha->length();
+			for (long i=0; i< tango_vusha->length(); i++)
+			{
+				taco_vusha.sequence[i] = (*tango_vusha)[i];
+			}
+                        dc_datacmd.argout_type = argout_type;
+                        dc_datacmd.argout = &taco_vusha;
+                        status = dc_dataconvert(&dc_datacmd, 1, &dc_error);
+                        taco_opaque->length = dc_datacmd.length;
+                        taco_opaque->sequence = dc_datacmd.sequence;              
+			free(taco_vusha.sequence);
+			break;
+		}
+
 		case D_VAR_LONGARR :
-		case D_VAR_ULONGARR :
 		{
 			DevVarLongArray taco_vla;
 			Tango_DevVarLongArray *tango_vla;
 
-			if ((tango_type != Tango_DEVVAR_LONGARRAY) &&
-			    (tango_type != Tango_DEVVAR_ULONGARRAY))
+			if (tango_type != Tango_DEVVAR_LONGARRAY)
 			{
 				throw_exception((const char*)"tango argout type is not Tango_DEVVAR_LONGARRAY", 
 				                (const char *)"tango_any_to_argout_raw()",
@@ -1568,6 +1802,34 @@ static void tango_any_to_argout_raw(long argout_type, long tango_type, CORBA_Any
 			break;
 		}
 
+		case D_VAR_ULONGARR :
+		{
+			DevVarULongArray taco_vula;
+			Tango_DevVarULongArray *tango_vula;
+
+			if (tango_type != Tango_DEVVAR_ULONGARRAY)
+			{
+				throw_exception((const char*)"tango argout type is not Tango_DEVVAR_ULONGARRAY", 
+				                (const char *)"tango_any_to_argout_raw()",
+				                DevErr_IncompatibleCmdArgumentTypes ,
+				                Tango_APILIB);
+			}
+			received >>= tango_vula;
+			taco_vula.sequence = (unsigned long*)malloc(tango_vula->length()*sizeof(unsigned long));
+			taco_vula.length = tango_vula->length();
+			for (long i=0; i< tango_vula->length(); i++)
+			{
+				taco_vula.sequence[i] = (*tango_vula)[i];
+			}
+                        dc_datacmd.argout_type = argout_type;
+                        dc_datacmd.argout = &taco_vula;
+                        status = dc_dataconvert(&dc_datacmd, 1, &dc_error);
+                        taco_opaque->length = dc_datacmd.length;
+                        taco_opaque->sequence = dc_datacmd.sequence;              
+			free(taco_vula.sequence);
+			break;
+		}
+
 		case D_VAR_FLOATARR :
 		{
 			DevVarFloatArray taco_vfa;
@@ -1882,7 +2144,6 @@ static long tango_dev_error_string(Tango_DevFailed tango_exception)
 			dev_error_string = (char*)realloc(dev_error_string,strlen(dev_error_string)+strlen(tango_exception.errors[i].reason.in())+1);
 			sprintf(dev_error_string+strlen(dev_error_string),"%s",tango_exception.errors[i].reason.in());
 		}
-		printf("tango_dev_error_string(): %s",tango_exception.errors[i].reason.in());
 	}
 	return(DS_OK);
 }
