@@ -1,5 +1,5 @@
 static char RcsId[] = 
-"@(#)$Header: util_api.c,v 8.18 2000/11/12 13:24:01 goetz Rel $";
+"@(#)$Header: util_api.c,v 8.20 2001/01/08 12:05:09 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -16,15 +16,27 @@ static char RcsId[] =
 
  Original   :	April 1993
 
- $Revision: 8.18 $
- $Date: 2000/11/12 13:24:01 $
+ $Revision: 8.20 $
+ $Date: 2001/01/08 12:05:09 $
 
  $Author: goetz $
 
  $Log:	util_api.c,v $
- * Revision 8.18  2000/11/12  13:24:01  13:24:01  goetz (Andy Goetz)
- * added dynamic error handling; improved TANGO error treatment
+ * Revision 8.20  2001/01/08  12:05:09  12:05:09  goetz (Andy Goetz)
+ * added patch by B.Pedersen to support querying events
  * 
+ Revision 8.31  2000/07/28 09:59:53  dserver
+ BP: added dev_query_event to get event parameters
+     -> new data struture  for event list in server
+        events have to be registered by the server,
+        similar to commands.
+
+ Revision 8.19  2000/12/11 12:06:34  goetz
+ fixed bugs with TANGO interface returning unsigned values and states
+
+ Revision 8.18  2000/11/12 13:24:01  goetz
+ added dynamic error handling; improved TANGO error treatment
+
  Revision 8.17  1900/09/26 13:36:22  goetz
  tango_dev_putget() and tango_dev_putget_raw() implement immediate reconnection
 
@@ -283,7 +295,7 @@ extern server_connections	svr_conns [];
  *  Table of command CLASS resources, read for dev_cmd_query()
  */
 
-db_resource   res_tab [] = {
+static db_resource   res_tab [] = {
 	{(char *)"In_Type",  D_STRING_TYPE, NULL},
 	{(char *)"Out_Type", D_STRING_TYPE, NULL},
 };
