@@ -14,15 +14,18 @@
  Original:	June 1991
 
 
- $Revision: 4.32 $
- $Date: 98/12/11 13:09:07 $
+ $Revision: 4.33 $
+ $Date: 2001/01/10 10:20:18 $
 
  $Author: goetz $
 
- $Log:	DevCmds.h,v $
- * Revision 4.32  98/12/11  13:09:07  13:09:07  goetz (Andy Goetz)
- * added new PLC command DevReadIntWordSeq
- * 
+ $Log: DevCmds.h,v $
+ Revision 4.33  2001/01/10 10:20:18  goetz
+ added B.Perdersen's patch to query events
+
+ Revision 4.32  1998/12/11 13:09:07  goetz
+ added new PLC command DevReadIntWordSeq
+
  * Revision 4.31  98/07/03  13:54:35  13:54:35  taurel (E.Taurel)
  * Added a new command code for AB (DevGetDsConfig)
  * 
@@ -128,12 +131,13 @@
  */
 #ifdef _IDENT
 static char DevCmdsh[] = 
-"@(#)$Header: DevCmds.h,v 4.32 98/12/11 13:09:07 goetz Exp $";
+"@(#)$Header: /segfs/dserver/system/api/cmds_err/include/RCS/DevCmds.h,v 4.33 2001/01/10 10:20:18 goetz Exp $";
 #endif /* _IDENT */
 
 
 #if !defined(FORTRAN)
 typedef long DevCommand;
+typedef long DevEvent;
 typedef long DevArgType;
 typedef long int (*DevCommandFunction)();
 #endif /* FORTRAN */
@@ -809,6 +813,15 @@ typedef struct _DevCommandListEntry {
 	       DevCommandListEntry;
 
 typedef struct _DevCommandListEntry *DevCommandList;
+
+/* events */
+typedef struct _DevEventListEntry {
+                                     DevEvent         event;
+                                     DevArgType         argout_type;
+                                  }
+               DevEventListEntry;
+
+typedef struct _DevEventListEntry *DevEventList;    
 #endif /* FORTRAN */
 
 #endif /* _DevCmds_h */
