@@ -13,12 +13,18 @@
  Original:	January 1991
 
 
- $Revision: 5.18 $
- $Date: 1999/07/08 14:10:49 $
+ $Revision: 5.20 $
+ $Date: 2001/01/08 12:17:37 $
 
  $Author: goetz $
 
  $Log: dev_xdr.h,v $
+ Revision 5.20  2001/01/08 12:17:37  goetz
+ added patch by B.Pedersen to support querying events
+
+ Revision 5.19  2000/10/02 12:08:48  goetz
+ removed stderr from api_xdr.c
+
  Revision 5.18  1999/07/08 14:10:49  goetz
  changed _LPfd_set type for Linux in macros.h
 
