@@ -1,6 +1,6 @@
 
 static char RcsId[] =
-"@(#)$Header: /segfs/dserver/dev/system/xdr/src/RCS/api_xdr.c,v 5.18 1999/07/08 14:10:46 goetz Rel $";
+"@(#)$Header: /segfs/dserver/system/xdr/src/RCS/api_xdr.c,v 5.20 2001/01/08 12:17:35 goetz Rel $";
 /*+*******************************************************************
 
  File:          api_xdr.c
@@ -14,12 +14,24 @@ static char RcsId[] =
  Original:      January 1991
 
 
-$Revision: 5.18 $
-$Date: 1999/07/08 14:10:46 $
+$Revision: 5.20 $
+$Date: 2001/01/08 12:17:35 $
 
 $Author: goetz $
 
 $Log: api_xdr.c,v $
+Revision 5.20  2001/01/08 12:17:35  goetz
+added patch by B.Pedersen to support querying events
+
+Revision 8.31  2000/07/28 09:59:53  dserver
+BP: added dev_query_event to get event parameters
+    -> new data struture  for event list in server
+       events have to be registered by the server,
+       similar to commands.
+
+Revision 5.19  2000/10/02 12:08:45  goetz
+removed stderr from api_xdr.c
+
 Revision 5.18  1999/07/08 14:10:46  goetz
 changed _LPfd_set type for Linux in macros.h
 
@@ -223,7 +235,7 @@ xdr_DevVarArgument (xdrs, objp)
 #ifdef _NT
 		   PRINTF(msg);
 #else
-		   fprintf (stderr, "%s\n", msg);
+		   printf ("%s\n", msg);
 #endif
            return (FALSE);
            }
@@ -289,7 +301,7 @@ xdr__server_data(xdrs, objp)
 #ifdef _NT
 	   PRINTF(msg);
 #else
-	   fprintf (stderr, "%s\n", msg);
+	   printf ("%s\n", msg);
 #endif
 	   return (FALSE);
 	   }
@@ -342,7 +354,7 @@ xdr__client_data(xdrs, objp)
 #ifdef _NT
 	   PRINTF(msg);
 #else
-	   fprintf (stderr, "%s\n", msg);
+	   printf ("%s\n", msg);
 #endif
 
 	   objp->argout   = NULL;
@@ -407,7 +419,7 @@ xdr__client_raw_data(xdrs, objp)
 #ifdef _NT
 		  PRINTF(msg);
 #else
-	      fprintf (stderr, "%s\n", msg);
+	      printf ("%s\n", msg);
 #endif
 	      return (FALSE);
 	      }
@@ -438,7 +450,7 @@ xdr__client_raw_data(xdrs, objp)
 #ifdef _NT
 		  PRINTF(msg);
 #else
-	      fprintf (stderr, "%s\n", msg);
+	      printf ("%s\n", msg);
 #endif
 	      return (FALSE);
 	      }
@@ -661,6 +673,49 @@ xdr__dev_query_out(xdrs, objp)
 
 
 
+/* event query */
+bool_t
+xdr__dev_event_info(xdrs, objp)
+	XDR *xdrs;
+	_dev_event_info *objp;
+{
+	if (!xdr_long(xdrs, &objp->event)) {
+		return (FALSE);
+	}
+	if (!xdr_long(xdrs, &objp->out_type)) {
+		return (FALSE);
+	}
+	return (TRUE);
+}
+
+
+
+bool_t
+xdr__dev_queryevent_out(xdrs, objp)
+	XDR *xdrs;
+	_dev_queryevent_out *objp;
+{
+	if (!xdr_array(xdrs, (caddr_t *)&objp->sequence,
+            (u_int *)&objp->length, MAXU_INT, sizeof(_dev_event_info),
+	     (xdrproc_t)xdr__dev_event_info)) {
+		return (FALSE);
+	}
+	if (!xdr_opaque(xdrs, (caddr_t)objp->class_name, SHORT_NAME_SIZE)) {
+		return (FALSE);
+	}
+	if (!xdr_long(xdrs, &objp->error)) {
+		return (FALSE);
+	}
+	if (!xdr_long(xdrs, &objp->status)) {
+		return (FALSE);
+	}
+	if (!xdr_DevVarArgumentArray(xdrs, &objp->var_argument)) {
+		return (FALSE);
+	}
+	return (TRUE);
+}	
+/*end eventquery*/
+
 /*
  *  internal xdr_routines for message service data transfer 
  */
