@@ -1,5 +1,5 @@
 static char RcsId[] =
-"@(#)$Header: /segfs/dserver/dev/system/xdr/src/RCS/dev_xdr.c,v 5.18 1999/07/08 14:10:46 goetz Rel $";
+"@(#)$Header: /segfs/dserver/system/xdr/src/RCS/dev_xdr.c,v 5.20 2001/01/08 12:17:35 goetz Rel $";
 
 /*+*******************************************************************
 
@@ -13,12 +13,18 @@ static char RcsId[] =
 
  Original:	January 1991
 
-$Revision: 5.18 $
-$Date: 1999/07/08 14:10:46 $
+$Revision: 5.20 $
+$Date: 2001/01/08 12:17:35 $
 
 $Author: goetz $
 
 $Log: dev_xdr.c,v $
+Revision 5.20  2001/01/08 12:17:35  goetz
+added patch by B.Pedersen to support querying events
+
+Revision 5.19  2000/10/02 12:08:45  goetz
+removed stderr from api_xdr.c
+
 Revision 5.18  1999/07/08 14:10:46  goetz
 changed _LPfd_set type for Linux in macros.h
 
